@@ -132,15 +132,15 @@ gedit_close_confirmation_dialog_init (GeditCloseConfirmationDialog *dlg)
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dlg)->vbox), 14);
 	gtk_window_set_resizable (GTK_WINDOW (dlg), FALSE);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dlg), FALSE);
-  
+
 	gtk_window_set_title (GTK_WINDOW (dlg), "");
-	
+
 	gtk_window_set_modal (GTK_WINDOW (dlg), TRUE);
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (dlg), TRUE);
 
-	gedit_dialog_add_button (GTK_DIALOG (dlg),
-				_("Do_n't save"), GTK_STOCK_NO,
-				GTK_RESPONSE_NO);
+	gtk_dialog_add_button (GTK_DIALOG (dlg),
+			       _("Close _without Saving"),
+			       GTK_RESPONSE_NO);
 
 	gtk_dialog_add_buttons (GTK_DIALOG (dlg),
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -622,10 +622,7 @@ build_multiple_docs_dialog (GeditCloseConfirmationDialog *dlg)
 	hbox = gtk_hbox_new (FALSE, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
   	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), 
-			    hbox, 
-	                    FALSE, 
-			    FALSE, 
-			    0);
+			    hbox, TRUE, TRUE, 0);
 
 	/* Image */
 	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, 
@@ -634,7 +631,7 @@ build_multiple_docs_dialog (GeditCloseConfirmationDialog *dlg)
 	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 
 	vbox = gtk_vbox_new (FALSE, 12);
-	gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
 
 	/* Primary label */
 	primary_label = gtk_label_new (NULL);
