@@ -32,15 +32,14 @@
 #endif
 
 #include <string.h>
+#include <time.h>
 
+#include <glib/gi18n.h>
 #include <glade/glade-xml.h>
-#include <libgnome/gnome-i18n.h>
 #include <gconf/gconf-client.h>
 #include <libgnome/gnome-help.h>
 #include <libgnome/gnome-config.h>
 
-#include <time.h>
-
 #include <gedit/gedit-plugin.h>
 #include <gedit/gedit-debug.h>
 #include <gedit/gedit-menus.h>
@@ -440,9 +439,6 @@ create_formats_list (GtkWidget *listview, const gchar* sel_format)
 	gedit_debug (DEBUG_PLUGINS, "");
 
 	g_return_if_fail (listview != NULL);
-
-	/* Create model, it also add model to the tree view */
-	create_model (listview, sel_format);
 	
 	/* the Available formats column */
 	cell = gtk_cell_renderer_text_new ();
@@ -450,6 +446,9 @@ create_formats_list (GtkWidget *listview, const gchar* sel_format)
 			"text", COLUMN_FORMATS, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (listview), column);
 
+	/* Create model, it also add model to the tree view */
+	create_model (listview, sel_format);
+
 	g_signal_connect (G_OBJECT (listview), "realize", 
 			G_CALLBACK (scroll_to_selected), NULL);
 
